@@ -11,11 +11,11 @@ decryption_data = [
 
 
 @pytest.mark.parametrize("data, expected", decryption_data)
-def test_project_visibility(data, expected):
+def test_project_visibility(data: bytes, expected: bytes) -> None:
     assert ms_ovba_crypto.decrypt(data) == expected
 
 
-def test_version_exception():
+def test_version_exception() -> None:
     data = b'\x15\x16\xCA\xF1\xD6\xF9\xD7\xF9\xD7\x06'
     with pytest.raises(Exception):
         ms_ovba_crypto.decrypt(data)
